@@ -375,6 +375,23 @@ sub string {
     }
 }
 
+=head2 stringz
+
+Returns a list of bytes representing the C<$str> with a zero
+terminator at the end. The "\0" byte will be added unless
+seen as the last element in the list.
+
+Only ServiceClassName needs this, see L<DOCSIS::ConfigFile::Syminfo>
+for more details.
+
+=cut
+
+sub stringz {
+    my @bytes = string(@_);
+    push @bytes, 0 if(@bytes == 0 or $bytes[-1] ne "\0");
+    return @bytes;
+}
+
 =head2 hexstr
 
 Will encode any hex encoded string into a list of bytes. The string
